[![kinisi Logo](https://github.com/bjmorgan/kinisi/raw/master/docs/source/logo/kinisi_logo.png)](https://kinisi.readthedocs.io)

kee-nee-si

[![Build Status](https://travis-ci.com/bjmorgan/kinisi.svg?token=euD1Dm5xCYsSwqy8dGzr&branch=master)](https://travis-ci.com/bjmorgan/kinisi)
[![Test Coverage](https://api.codeclimate.com/v1/badges/3e64239fb6cb6c837b62/test_coverage)](https://codeclimate.com/github/bjmorgan/kinisi/test_coverage)
[![Documentation Status](https://readthedocs.org/projects/kinisi/badge/?version=latest)](https://kinisi.readthedocs.io/en/latest/?badge=latest)

Uncertainty analysis and model comparison for atomistic molecular dynamics.

```
python setup.py build
python setup.py install
pytest
```
